@@ -17,9 +17,13 @@ DevLake MCP - Claude Code Hooks 模块
     - record_session: 会话结束时触发
 """
 
-# 自动初始化 Git 环境变量（hooks 模块导入时执行）
+# 配置将在实际使用时加载，而不是在导入时
+# 这样可以避免在测试环境中导致问题
 from devlake_mcp.config import DevLakeConfig
-DevLakeConfig.from_env(include_git=True)
+
+def _initialize_hooks_config():
+    """初始化 Hooks 配置（按需调用）"""
+    return DevLakeConfig.from_env(include_git=True)
 
 # 导入所有 hook 模块
 from devlake_mcp.hooks import (
