@@ -21,7 +21,7 @@ from datetime import datetime
 from typing import Callable
 
 # 导入通用工具函数（避免代码重复）
-from devlake_mcp.utils import get_temp_dir, get_temp_file_path
+from devlake_mcp.utils import get_data_dir, get_temp_file_path
 from devlake_mcp.constants import HOOK_LOG_DIR
 
 # 注意：hook_utils 是基础模块，不导入其他 hooks 模块以避免循环依赖
@@ -42,10 +42,10 @@ def save_to_local_queue(queue_name: str, data: dict):
         data: 要保存的数据字典
 
     文件格式:
-        /tmp/claude_hooks/{queue_name}/{timestamp}.json
+        ~/.devlake/{queue_name}/{timestamp}.json
     """
     try:
-        queue_dir = get_temp_dir() / queue_name
+        queue_dir = get_data_dir(persistent=True) / queue_name
         queue_dir.mkdir(parents=True, exist_ok=True)
 
         # 使用时间戳作为文件名，确保唯一性
@@ -67,14 +67,14 @@ def cleanup_old_files(directory: str, max_age_hours: int = 24):
     清理指定目录中的过期文件
 
     Args:
-        directory: 目录名称（相对于临时目录）
+        directory: 目录名称（相对于持久化数据目录）
         max_age_hours: 最大保留时间（小时）
 
     示例:
         cleanup_old_files('failed_session_uploads', max_age_hours=168)  # 7天
     """
     try:
-        target_dir = get_temp_dir() / directory
+        target_dir = get_data_dir(persistent=True) / directory
         if not target_dir.exists():
             return
 
@@ -101,10 +101,18 @@ def run_async(func: Callable):
     """
     异步执行装饰器，让 hook 立即返回，后台执行任务
 
-    原理：
-    - 使用 os.fork() 创建子进程（Unix-like 系统）
-    - 父进程立即退出（返回给 Claude）
-    - 子进程继续执行实际的 API 调用等耗时操作
+    原理（标准的双重 fork daemon 化）：
+    1. 第一次 fork：创建子进程，父进程立即退出
+    2. setsid()：子进程创建新会话，脱离控制终端
+    3. 第二次 fork：创建孙进程，第一个子进程退出
+    4. 孙进程（真正的 daemon）执行实际工作
+
+    为什么需要双重 fork？
+    - 单次 fork：子进程仍在父进程的会话中，可能被 Claude Code 等待
+    - setsid()：创建新会话，但子进程成为 session leader
+    - 第二次 fork：确保孙进程不是 session leader，完全独立
+
+    参考：Stevens "Advanced Programming in the UNIX Environment"
 
     使用方法：
         @run_async
@@ -116,14 +124,9 @@ def run_async(func: Callable):
             main()
 
     优点：
-    - hook 0 延迟，不阻塞 Claude 响应
+    - hook 0 延迟，不阻塞 Claude 响应（即使 API 超时 10 秒）
+    - 完全脱离父进程会话，不会被等待
     - API 调用慢或失败不影响用户体验
-    - 子进程独立运行，父进程立即退出
-    - 不需要序列化函数（避免 pickle 问题）
-
-    新增功能（v0.2.x）：
-    - Hook 执行后自动检查并重试失败的上传记录
-    - 非阻塞执行，不影响主流程
 
     注意：
     - 只在 Unix-like 系统（macOS/Linux）使用 fork
@@ -137,31 +140,82 @@ def run_async(func: Callable):
             _check_and_retry_uploads()  # 同步模式下也检查重试
             return
 
-        # 使用 os.fork() 创建子进程
+        # === 第一次 fork ===
         try:
             pid = os.fork()
         except OSError:
             # fork 失败，降级为同步执行
             func(*args, **kwargs)
-            _check_and_retry_uploads()  # 同步模式下也检查重试
+            _check_and_retry_uploads()
             return
 
         if pid > 0:
-            # 父进程：立即退出
-            sys.exit(0)
-        else:
-            # 子进程：执行实际的 hook 逻辑
+            # 父进程：立即退出（返回给 Claude Code）
+            os._exit(0)
+
+        # === 第一个子进程 ===
+        try:
+            # 创建新会话，脱离控制终端
+            # 此时子进程成为 session leader
+            os.setsid()
+        except OSError:
+            # setsid 失败，退出
+            os._exit(1)
+
+        # === 第二次 fork ===
+        try:
+            pid = os.fork()
+        except OSError:
+            # fork 失败，退出
+            os._exit(1)
+
+        if pid > 0:
+            # 第一个子进程：退出
+            # 让孙进程被 init 进程接管
+            os._exit(0)
+
+        # === 孙进程（真正的 daemon）===
+        try:
+            # 1. 读取 stdin 内容（在关闭文件描述符之前）
+            from io import StringIO
             try:
-                # 1. 执行主 hook 逻辑
-                func(*args, **kwargs)
-
-                # 2. 检查并重试失败的上传记录（非阻塞）
-                _check_and_retry_uploads()
-
-                sys.exit(0)
+                stdin_content = sys.stdin.read()
             except Exception:
-                # 子进程中的异常不影响父进程
-                sys.exit(1)
+                stdin_content = ''
+
+            # 2. 关闭并重定向标准文件描述符（关键！）
+            # 这是 daemon 化的必要步骤，确保 subprocess.run 不会等待
+            sys.stdout.flush()
+            sys.stderr.flush()
+
+            # 关闭标准输入/输出/错误的文件描述符
+            os.close(0)  # stdin
+            os.close(1)  # stdout
+            os.close(2)  # stderr
+
+            # 重新打开到 /dev/null 或日志文件
+            # stdin -> /dev/null
+            os.open('/dev/null', os.O_RDONLY)  # 返回 fd 0
+
+            # stdout 和 stderr -> 保留日志功能
+            # 注意：由于我们已经配置了 logging 到文件，这里重定向到 /dev/null 不影响日志
+            os.open('/dev/null', os.O_WRONLY)  # 返回 fd 1 (stdout)
+            os.open('/dev/null', os.O_WRONLY)  # 返回 fd 2 (stderr)
+
+            # 3. 用 StringIO 替换 Python 的 sys.stdin（让代码能正常读取）
+            sys.stdin = StringIO(stdin_content)
+
+            # 4. 执行主 hook 逻辑
+            func(*args, **kwargs)
+
+            # 5. 检查并重试失败的上传记录（非阻塞）
+            _check_and_retry_uploads()
+
+            # daemon 正常退出
+            os._exit(0)
+        except Exception:
+            # daemon 异常退出
+            os._exit(1)
 
     return wrapper
 
