@@ -25,18 +25,18 @@ from datetime import datetime
 from pathlib import Path
 
 # 导入公共工具（使用包导入）
+from devlake_mcp.enums import IDEType
 from devlake_mcp.hooks.hook_utils import run_async
-from devlake_mcp.utils import get_temp_dir, get_temp_file_path, compress_content
+from devlake_mcp.utils import get_temp_file_path, compress_content
 from devlake_mcp.git_utils import get_git_context_from_file
 from devlake_mcp.client import DevLakeClient
 from devlake_mcp.retry_queue import save_failed_upload
-from devlake_mcp.session_manager import check_and_switch_session
 from devlake_mcp.generation_manager import get_current_generation_id
-from devlake_mcp.logging_config import configure_logging
+from devlake_mcp.logging_config import configure_logging, get_log_dir
 from devlake_mcp.constants import HOOK_LOG_DIR
 
 # 配置日志（启动时调用一次）
-configure_logging(log_dir=HOOK_LOG_DIR, log_file='post_tool_use.log')
+configure_logging(log_dir=get_log_dir(HOOK_LOG_DIR), log_file='post_tool_use.log')
 logger = logging.getLogger(__name__)
 
 
@@ -161,6 +161,11 @@ def should_collect_file(file_path: str) -> bool:
 
 @run_async
 def main():
+    """
+    PostToolUse Hook 主逻辑
+
+    注意：所有异常都被捕获并静默处理，确保不阻塞 Claude
+    """
     temp_file = None  # 初始化临时文件路径
     try:
         # 读取 Hook 输入
@@ -171,25 +176,16 @@ def main():
         tool_input = input_data.get('tool_input', {})
         session_id = input_data.get('session_id')
 
-        # 获取当前工作目录（需要在检查会话前获取）
+        # 获取当前工作目录（用于获取 Git 信息）
         cwd = input_data.get('cwd', os.getcwd())
 
-        # 检查会话是否切换（如果切换会自动结束旧会话）
-        if session_id:
-            try:
-                switched = check_and_switch_session(session_id, cwd, ide_type='claude_code')
-                if switched:
-                    logger.info(f'检测到会话切换，旧会话已自动结束，新会话: {session_id}')
-            except Exception as e:
-                logger.error(f'会话切换检查失败: {e}')
-
         # 只处理 PostToolUse 事件
         if hook_event_name != 'PostToolUse':
-            sys.exit(0)
+            return
 
         # 只处理文件修改相关的工具
         if tool_name not in ['Write', 'Edit', 'NotebookEdit']:
-            sys.exit(0)
+            return
 
         logger.debug(f'PostToolUse Hook 触发 - tool: {tool_name}, session: {session_id}')
 
@@ -197,7 +193,7 @@ def main():
         file_path = tool_input.get('file_path') or tool_input.get('notebook_path')
         if not file_path:
             logger.debug('没有 file_path，跳过')
-            sys.exit(0)
+            return
 
         # 转换为绝对路径
         if not os.path.isabs(file_path):
@@ -207,7 +203,7 @@ def main():
         # 检查是否应该采集
         if not should_collect_file(file_path):
             logger.debug(f'文件不需要采集（敏感文件或二进制文件）: {file_path}')
-            sys.exit(0)
+            return
 
         logger.info(f'开始处理文件变更: {file_path}')
 
@@ -267,7 +263,7 @@ def main():
                 logger.warning(f'路径转换失败: {e}')
 
         # 7. 获取 prompt_uuid（关联到具体的 prompt）
-        prompt_uuid = get_current_generation_id(session_id)
+        prompt_uuid = get_current_generation_id(session_id, ide_type=IDEType.CLAUDE_CODE)
         logger.debug(f'获取到 prompt_uuid: {prompt_uuid}')
 
         # 8. 构造上报数据（不包含 diff 计算结果）
@@ -317,9 +313,7 @@ def main():
             except Exception as e:
                 logger.warning(f'清理临时文件失败: {e}')
 
-        # 静默退出
-        sys.exit(0)
-
 
 if __name__ == '__main__':
     main()
+    sys.exit(0)  # 唯一的 exit 点
