@@ -19,12 +19,12 @@ from pathlib import Path
 from datetime import datetime
 
 # 导入公共工具（使用包导入）
-from devlake_mcp.utils import get_temp_dir, get_temp_file_path
-from devlake_mcp.logging_config import configure_logging
+from devlake_mcp.utils import get_temp_file_path
+from devlake_mcp.logging_config import configure_logging, get_log_dir
 from devlake_mcp.constants import HOOK_LOG_DIR
 
 # 配置日志（启动时调用一次）
-configure_logging(log_dir=HOOK_LOG_DIR, log_file='pre_tool_use.log')
+configure_logging(log_dir=get_log_dir(HOOK_LOG_DIR), log_file='pre_tool_use.log')
 logger = logging.getLogger(__name__)
 
 
@@ -54,6 +54,11 @@ def save_before_content(session_id: str, file_path: str, content: str):
 
 
 def main():
+    """
+    PreToolUse Hook 主逻辑
+
+    注意：所有异常都被捕获并静默处理，确保不阻塞 Claude
+    """
     try:
         input_data = json.load(sys.stdin)
 
@@ -63,13 +68,13 @@ def main():
 
         # 只处理文件修改工具
         if tool_name not in ['Write', 'Edit', 'NotebookEdit']:
-            sys.exit(0)
+            return
 
         # 获取文件路径
         file_path = tool_input.get('file_path')
         if not file_path:
             logger.debug(f'工具 {tool_name} 没有 file_path，跳过')
-            sys.exit(0)
+            return
 
         # 转换为绝对路径
         if not os.path.isabs(file_path):
@@ -89,7 +94,7 @@ def main():
             except Exception as e:
                 # 读取失败（如二进制文件），跳过
                 logger.warning(f'读取文件失败（可能是二进制文件）: {e}')
-                sys.exit(0)
+                return
         else:
             logger.debug('文件不存在（新建文件）')
 
@@ -97,14 +102,11 @@ def main():
         save_before_content(session_id, file_path, before_content)
         logger.info(f'成功保存 before_content: {file_path}')
 
-        # 成功，静默退出
-        sys.exit(0)
-
     except Exception as e:
         # 任何异常都静默失败，不影响 AI 执行
         logger.error(f'PreToolUse Hook 执行失败: {e}', exc_info=True)
-        sys.exit(0)
 
 
 if __name__ == '__main__':
     main()
+    sys.exit(0)  # 唯一的 exit 点
