@@ -22,6 +22,7 @@ import os
 import logging
 from datetime import datetime
 from pathlib import Path
+from typing import Optional, Tuple
 
 # 导入公共工具（使用包导入）
 from devlake_mcp.hooks.transcript_utils import (
@@ -31,34 +32,33 @@ from devlake_mcp.hooks.transcript_utils import (
 )
 from devlake_mcp.hooks.hook_utils import run_async
 from devlake_mcp.client import DevLakeClient
-from devlake_mcp.session_manager import clear_session
-from devlake_mcp.logging_config import configure_logging
+from devlake_mcp.retry_queue import save_failed_upload
+from devlake_mcp.logging_config import configure_logging, get_log_dir
 from devlake_mcp.constants import HOOK_LOG_DIR
+from devlake_mcp.generation_manager import end_generation
+from devlake_mcp.enums import IDEType
 
 # 配置日志（启动时调用一次）
-configure_logging(log_dir=HOOK_LOG_DIR, log_file='record_session.log')
+configure_logging(log_dir=get_log_dir(HOOK_LOG_DIR), log_file='record_session.log')
 logger = logging.getLogger(__name__)
 
 
-def _validate_input(input_data: dict) -> tuple[str, str]:
+def _validate_input(input_data: dict) -> Optional[Tuple[str, str]]:
     """验证输入数据的有效性
 
     Args:
         input_data: Hook 输入数据
 
     Returns:
-        tuple[session_id, transcript_path]
-
-    Raises:
-        SystemExit: 如果验证失败，退出程序
+        tuple[session_id, transcript_path] 或 None（验证失败时）
     """
     hook_event_name = input_data.get('hook_event_name')
     if hook_event_name != 'SessionEnd':
-        sys.exit(0)
+        return None
 
     session_id = input_data.get('session_id')
     if not session_id:
-        sys.exit(0)
+        return None
 
     transcript_path = input_data.get('transcript_path', '')
     return session_id, transcript_path
@@ -80,8 +80,14 @@ def _update_session(client: DevLakeClient, session_id: str, conversation_rounds:
 
     try:
         client.update_session(session_id, update_data)
-    except Exception:
+    except Exception as e:
         logger.error(f'Failed to update session {session_id}', exc_info=True)
+        # 保存到本地队列（支持自动重试）
+        save_failed_upload(
+            queue_type='session',
+            data=update_data,
+            error=str(e)
+        )
 
 
 def _upload_transcript(client: DevLakeClient, session_id: str,
@@ -98,10 +104,12 @@ def _upload_transcript(client: DevLakeClient, session_id: str,
         1. 读取 transcript 原始内容
         2. 智能压缩（大于 1MB 时自动启用 gzip 压缩）
         3. 上传到 DevLake API
+        4. 失败时保存到重试队列
     """
     if not transcript_path or not os.path.exists(transcript_path):
         return
 
+    transcript_data = None
     try:
         # 1. 读取原始内容
         transcript_content = read_transcript_content(transcript_path)
@@ -140,17 +148,32 @@ def _upload_transcript(client: DevLakeClient, session_id: str,
                 f"大小: {original_size} bytes"
             )
 
-    except Exception:
+    except Exception as e:
         logger.error(f'Failed to upload transcript for {session_id}', exc_info=True)
+        # 保存到本地队列（支持自动重试）
+        if transcript_data:
+            save_failed_upload(
+                queue_type='transcript',
+                data=transcript_data,
+                error=str(e)
+            )
 
 
 @run_async
 def main():
-    """SessionEnd Hook 主入口：记录会话结束信息"""
+    """
+    SessionEnd Hook 主逻辑：记录会话结束信息
+
+    注意：所有异常都被捕获并静默处理，确保不阻塞 Claude
+    """
     try:
         # 1. 读取并验证输入
         input_data = json.load(sys.stdin)
-        session_id, transcript_path = _validate_input(input_data)
+        validation_result = _validate_input(input_data)
+        if not validation_result:
+            return
+
+        session_id, transcript_path = validation_result
 
         # 2. 统计对话轮次
         conversation_rounds = count_user_messages(transcript_path)
@@ -164,20 +187,21 @@ def main():
         # 5. 上传 transcript 内容
         _upload_transcript(client, session_id, transcript_path, conversation_rounds)
 
-        # 6. 清空会话状态（SessionEnd 表示会话真正结束）
+        # 6. 清理 generation 状态文件（防止文件堆积）
         try:
-            clear_session()
-            logger.info(f'会话状态已清空: {session_id}')
+            end_generation(session_id, ide_type=IDEType.CLAUDE_CODE)
+            logger.info(f'已清理 generation 状态文件: {session_id}')
         except Exception as e:
-            logger.warning(f'清空会话状态失败: {e}')
+            # 清理失败不影响主流程
+            logger.warning(f'清理 generation 状态文件失败: {e}')
 
-        sys.exit(0)
+        logger.info(f'会话记录完成: {session_id}')
 
     except Exception:
         # 任何异常都静默失败，不阻塞 Claude
         logger.error('SessionEnd hook failed', exc_info=True)
-        sys.exit(0)
 
 
 if __name__ == '__main__':
     main()
+    sys.exit(0)  # 唯一的 exit 点
