@@ -34,12 +34,12 @@ from devlake_mcp.hooks.transcript_utils import (
 )
 from devlake_mcp.client import DevLakeClient
 from devlake_mcp.retry_queue import save_failed_upload
-from devlake_mcp.generation_manager import get_current_generation_id, end_generation
-from devlake_mcp.logging_config import configure_logging
+from devlake_mcp.generation_manager import get_current_generation_id
+from devlake_mcp.logging_config import configure_logging, get_log_dir
 from devlake_mcp.constants import HOOK_LOG_DIR
 
 # 配置日志（启动时调用一次）
-configure_logging(log_dir=HOOK_LOG_DIR, log_file='stop_hook.log')
+configure_logging(log_dir=get_log_dir(HOOK_LOG_DIR), log_file='stop_hook.log')
 logger = logging.getLogger(__name__)
 
 
@@ -121,6 +121,11 @@ def calculate_prompt_duration(user_message: dict, latest_response: dict) -> int:
 
 @run_async
 def main():
+    """
+    Stop Hook 主逻辑
+
+    注意：所有异常都被捕获并静默处理，确保不阻塞 Claude
+    """
     try:
         # 1. 从 stdin 读取 hook 输入
         input_data = json.load(sys.stdin)
@@ -133,13 +138,17 @@ def main():
 
         if not session_id or not transcript_path:
             logger.warning('缺少必要的 session_id 或 transcript_path')
-            sys.exit(0)
+            return
+
+        if not os.path.exists(transcript_path):
+            logger.info(f'Transcript 文件尚不存在（可能是新会话初始化）: {transcript_path}')
+            return
 
         # 2. 解析 transcript 获取最新的 Claude 响应
         latest_response = parse_latest_response(transcript_path)
         if not latest_response:
             logger.warning('无法解析最新的 Claude 响应')
-            sys.exit(0)
+            return
 
         logger.debug(f'最新响应 - uuid: {latest_response.get("uuid")}, '
                     f'parent: {latest_response.get("parent_uuid")}, '
@@ -149,19 +158,19 @@ def main():
         parent_uuid = latest_response.get('parent_uuid')
         if not parent_uuid:
             logger.error('响应中缺少 parent_uuid')
-            sys.exit(0)
+            return
 
         # 使用追溯函数找到真正的 user prompt UUID
         prompt_uuid = trace_to_user_message(transcript_path, parent_uuid)
         if not prompt_uuid:
             logger.warning(f'无法追溯到 user 消息（从 {parent_uuid}），可能是工具调用等特殊情况')
-            sys.exit(0)
+            return
 
         # 4. 获取完整的 user 消息信息
         user_message = get_user_message_by_uuid(transcript_path, prompt_uuid)
         if not user_message:
             logger.error(f'无法获取 user 消息 (UUID: {prompt_uuid})')
-            sys.exit(0)
+            return
 
         content_preview = user_message.get('content', '')[:100]
         logger.debug(f'User 消息 - uuid: {prompt_uuid}, '
@@ -177,7 +186,7 @@ def main():
         prompt_sequence = count_user_messages(transcript_path)
 
         # 6. 检查是否有 generation_id（决定使用哪个 UUID）
-        generation_id = get_current_generation_id(session_id)
+        generation_id = get_current_generation_id(session_id, ide_type='claude_code')
 
         # 优先使用 generation_id 作为 prompt_uuid，否则使用 transcript 中的 UUID
         final_prompt_uuid = generation_id if generation_id else prompt_uuid
@@ -226,9 +235,10 @@ def main():
                     error=str(e)
                 )
 
-            # 结束 generation（清空状态）
-            end_generation(session_id)
-            logger.debug(f'Generation 已结束: {generation_id}')
+            # 注意：不清空 generation 状态文件
+            # 原因：Stop Hook 可能被触发多次（多条 assistant 消息）
+            # 状态文件保留到下一次 UserPromptSubmit 时覆盖
+            logger.debug(f'Prompt 更新完成，保留 generation 状态: {generation_id}')
 
         else:
             # 情况 2：向后兼容（POST 创建）
@@ -258,14 +268,11 @@ def main():
             logger.error(f'更新 session 对话轮数失败 ({session_id}): {e}')
             # 更新轮数失败不影响主流程，不保存到队列
 
-        # 成功，静默退出
-        sys.exit(0)
-
     except Exception as e:
         # 任何异常都静默失败，不阻塞 Claude
         logger.error(f'Stop Hook 执行失败: {e}', exc_info=True)
-        sys.exit(0)
 
 
 if __name__ == '__main__':
     main()
+    sys.exit(0)  # 唯一的 exit 点
