@@ -510,8 +510,8 @@ def compress_transcript_content(
             f"Transcript 大小 {original_size} bytes > {threshold_bytes} bytes，开始压缩"
         )
 
-        # gzip 压缩
-        compressed_bytes = gzip.compress(content_bytes, compresslevel=6)
+        # gzip 压缩（使用最大压缩级别）
+        compressed_bytes = gzip.compress(content_bytes, compresslevel=9)
         compressed_size = len(compressed_bytes)
 
         # base64 编码（以便在 JSON 中传输）
@@ -545,3 +545,163 @@ def compress_transcript_content(
             'compressed_size': original_size,
             'compression_ratio': 0.0
         }
+
+
+def extract_session_id(transcript_path: str) -> Optional[str]:
+    """
+    从 transcript 文件中提取 session_id
+
+    提取策略：
+    1. 优先从任意消息的 sessionId 字段提取
+    2. 如果提取失败，从文件名提取（备用方案）
+
+    Args:
+        transcript_path: Transcript 文件路径
+
+    Returns:
+        session_id，如果无法提取返回 None
+    """
+    logger.debug(f"开始提取 session_id，transcript: {transcript_path}")
+
+    try:
+        with open(transcript_path, 'r', encoding='utf-8') as f:
+            # 读取第一行（通常包含 sessionId）
+            first_line = f.readline()
+            if not first_line:
+                logger.warning(f"Transcript 文件为空: {transcript_path}")
+                return _extract_session_id_from_filename(transcript_path)
+
+            msg = json.loads(first_line.strip())
+            session_id = msg.get('sessionId')
+
+            if session_id:
+                logger.debug(f"从消息中提取到 session_id: {session_id}")
+                return session_id
+
+            # 策略 2: 从文件名提取（备用）
+            logger.debug(f"消息中未找到 sessionId，尝试从文件名提取")
+            return _extract_session_id_from_filename(transcript_path)
+
+    except json.JSONDecodeError as e:
+        logger.warning(f"解析 JSON 失败: {e}，尝试从文件名提取")
+        return _extract_session_id_from_filename(transcript_path)
+    except Exception as e:
+        logger.error(f"提取 session_id 失败: {e}")
+        # 最后尝试从文件名提取
+        return _extract_session_id_from_filename(transcript_path)
+
+
+def _extract_session_id_from_filename(transcript_path: str) -> Optional[str]:
+    """
+    从文件名提取 session_id
+
+    支持格式：
+    - 普通会话: {uuid}.jsonl -> uuid
+    - Agent 会话: agent-{short_id}.jsonl -> agent-{short_id}
+
+    Args:
+        transcript_path: Transcript 文件路径
+
+    Returns:
+        session_id，如果无法提取返回 None
+    """
+    import re
+    from pathlib import Path
+
+    filename = Path(transcript_path).stem  # 去除 .jsonl 后缀
+
+    # UUID 格式: xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
+    uuid_pattern = r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
+    if re.match(uuid_pattern, filename, re.IGNORECASE):
+        logger.debug(f"从文件名提取到 UUID session_id: {filename}")
+        return filename
+
+    # Agent 格式: agent-{short_id}
+    if filename.startswith('agent-'):
+        logger.debug(f"从文件名提取到 Agent session_id: {filename}")
+        return filename
+
+    logger.warning(f"无法从文件名提取 session_id: {filename}")
+    return None
+
+
+def get_session_start_time(transcript_path: str) -> Optional[datetime]:
+    """
+    提取会话开始时间
+
+    从第一条有 timestamp 的消息中提取（跳过 summary 等没有 timestamp 的消息）
+
+    Args:
+        transcript_path: Transcript 文件路径
+
+    Returns:
+        会话开始时间（datetime 对象），如果无法提取返回 None
+    """
+    logger.debug(f"开始提取会话开始时间，transcript: {transcript_path}")
+
+    try:
+        with open(transcript_path, 'r', encoding='utf-8') as f:
+            # 遍历消息，找到第一条有 timestamp 的消息
+            for line_num, line in enumerate(f, start=1):
+                if not line.strip():
+                    continue
+
+                try:
+                    msg = json.loads(line.strip())
+                    timestamp_str = msg.get('timestamp')
+
+                    if timestamp_str:
+                        # 解析 ISO 8601 时间戳
+                        timestamp = datetime.fromisoformat(timestamp_str.replace('Z', '+00:00'))
+                        logger.debug(f"从第 {line_num} 行找到会话开始时间: {timestamp}")
+                        return timestamp
+                except json.JSONDecodeError as e:
+                    logger.debug(f"跳过第 {line_num} 行（JSON 解析失败）: {e}")
+                    continue
+
+        # 未找到任何有 timestamp 的消息
+        logger.warning(f"未找到任何有 timestamp 的消息: {transcript_path}")
+        return None
+
+    except (ValueError) as e:
+        logger.error(f"解析会话开始时间失败: {e}")
+        return None
+    except Exception as e:
+        logger.error(f"提取会话开始时间失败: {e}")
+        return None
+
+
+def is_session_ended(transcript_path: str) -> bool:
+    """
+    判断会话是否已结束
+
+    检查 transcript 文件中是否包含 summary 消息
+
+    Args:
+        transcript_path: Transcript 文件路径
+
+    Returns:
+        True 表示会话已结束，False 表示正在进行中
+    """
+    logger.debug(f"检查会话是否已结束，transcript: {transcript_path}")
+
+    try:
+        with open(transcript_path, 'r', encoding='utf-8') as f:
+            lines = f.readlines()
+
+        # 从后往前查找 summary 消息（通常在最后）
+        for line in reversed(lines):
+            try:
+                msg = json.loads(line.strip())
+                if msg.get('type') == 'summary':
+                    logger.debug(f"会话已结束（找到 summary 消息）: {transcript_path}")
+                    return True
+            except json.JSONDecodeError:
+                continue
+
+        logger.debug(f"会话正在进行中（未找到 summary 消息）: {transcript_path}")
+        return False
+
+    except Exception as e:
+        logger.error(f"检查会话状态失败: {e}")
+        return False
