@@ -23,12 +23,12 @@ from datetime import datetime, timedelta
 from typing import Dict, List, Any, Optional, Literal
 from dataclasses import dataclass, asdict
 
-from .utils import get_temp_dir
+from .utils import get_data_dir
 from .client import DevLakeClient
 from .config import DevLakeConfig
 
 # 队列类型定义
-QueueType = Literal['session', 'prompt', 'prompt_update', 'file_change']
+QueueType = Literal['session', 'prompt', 'prompt_update', 'file_change', 'transcript']
 
 # 模块级 logger
 logger = logging.getLogger(__name__)
@@ -41,7 +41,7 @@ logger = logging.getLogger(__name__)
 @dataclass
 class RetryMetadata:
     """重试元数据"""
-    queue_type: str  # session, prompt, prompt_update, file_change
+    queue_type: str  # session, prompt, prompt_update, file_change, transcript
     api_endpoint: str  # API 端点路径
     created_at: str  # 创建时间（ISO 8601）
     retry_count: int = 0  # 重试次数
@@ -98,6 +98,7 @@ QUEUE_TYPE_TO_ENDPOINT = {
     'prompt': '/api/ai-coding/prompts',
     'prompt_update': '/api/ai-coding/prompts',  # 更新操作使用相同端点
     'file_change': '/api/ai-coding/file-changes',
+    'transcript': '/api/ai-coding/transcripts',
 }
 
 # 队列目录名称映射
@@ -106,6 +107,7 @@ QUEUE_TYPE_TO_DIR = {
     'prompt': 'failed_prompt_uploads',
     'prompt_update': 'failed_prompt_update_uploads',  # 更新操作使用独立目录
     'file_change': 'failed_file_change_uploads',
+    'transcript': 'failed_transcript_uploads',
 }
 
 
@@ -160,7 +162,7 @@ def save_failed_upload(
             logger.error(f"未知的队列类型: {queue_type}")
             return False
 
-        queue_dir = get_temp_dir() / queue_dir_name
+        queue_dir = get_data_dir(persistent=True) / queue_dir_name
         queue_dir.mkdir(parents=True, exist_ok=True)
 
         # 创建元数据
@@ -242,7 +244,7 @@ def retry_failed_uploads(max_parallel: int = 3) -> Dict[str, Any]:
         # 遍历所有队列类型
         for queue_type in QUEUE_TYPE_TO_DIR.keys():
             queue_dir_name = QUEUE_TYPE_TO_DIR[queue_type]
-            queue_dir = get_temp_dir() / queue_dir_name
+            queue_dir = get_data_dir(persistent=True) / queue_dir_name
 
             if not queue_dir.exists():
                 continue
@@ -340,7 +342,7 @@ def cleanup_expired_failures(max_age_hours: Optional[int] = None) -> int:
 
         # 遍历所有队列目录
         for queue_dir_name in QUEUE_TYPE_TO_DIR.values():
-            queue_dir = get_temp_dir() / queue_dir_name
+            queue_dir = get_data_dir(persistent=True) / queue_dir_name
 
             if not queue_dir.exists():
                 continue
@@ -408,7 +410,7 @@ def get_queue_statistics() -> Dict[str, Any]:
 
     try:
         for queue_type, queue_dir_name in QUEUE_TYPE_TO_DIR.items():
-            queue_dir = get_temp_dir() / queue_dir_name
+            queue_dir = get_data_dir(persistent=True) / queue_dir_name
             queue_stats = {'total': 0, 'pending': 0, 'max_retried': 0}
 
             if queue_dir.exists():
@@ -493,7 +495,15 @@ def _retry_upload(
 
         # 根据队列类型调用不同的 API 方法
         if queue_type == 'session':
-            client.create_session(data)
+            # 智能判断：如果包含 session_end_time，说明是更新操作
+            if 'session_end_time' in data:
+                session_id = data.get('session_id')
+                if not session_id:
+                    return False, "session 更新缺少 session_id"
+                client.update_session(session_id, data)
+            else:
+                # 否则是创建操作
+                client.create_session(data)
         elif queue_type == 'prompt':
             client.create_prompt(data)
         elif queue_type == 'prompt_update':
@@ -507,6 +517,8 @@ def _retry_upload(
             if 'changes' not in data:
                 data = {'changes': [data]}
             client.create_file_changes(data['changes'])
+        elif queue_type == 'transcript':
+            client.create_transcript(data)
         else:
             return False, f"未知的队列类型: {queue_type}"
 
