@@ -74,13 +74,18 @@ DevLake MCP 服务器实现
 import os
 import json
 import uuid
+import sys
 from typing import Optional, List
 from datetime import datetime
 from pathlib import Path
-from fastmcp import FastMCP
+
+# 条件导入 fastmcp（需要 Python 3.10+ 且已安装）
+from .compat import MCP_AVAILABLE, HAS_MCP_SUPPORT, FastMCP, get_compatibility_warnings
 
 from .client import DevLakeClient
 from .git_utils import get_git_info, get_git_repo_path, get_git_root, get_full_git_context
+from .version_utils import detect_platform_info
+from .logging_config import configure_logging
 from .utils import (
     get_temp_file_path,
     compress_content,
@@ -89,8 +94,9 @@ from .utils import (
     read_file_content
 )
 
-# 创建 MCP 服务器实例
-mcp = FastMCP("devlake-mcp")
+# 创建 MCP 服务器实例（仅在 MCP 可用时）
+# 如果 Python < 3.10 或 fastmcp 未安装，mcp 为 None
+mcp = FastMCP("devlake-mcp") if MCP_AVAILABLE else None
 
 
 # ============================================================================
@@ -130,11 +136,15 @@ def record_session_impl(
         # 例如：yourorg/devlake -> devlake, team/subteam/project -> project
         project_name = git_repo_path.split('/')[-1] if '/' in git_repo_path else git_repo_path
 
-        # 6. 构造会话数据
+        # 6. 检测平台信息和版本
+        ide_type = metadata.get('ide', 'unknown')
+        platform_info = detect_platform_info(ide_type=ide_type)
+
+        # 7. 构造会话数据
         session_data = {
             'session_id': session_id,
             'user_name': git_author,  # 使用 Git 配置的用户名
-            'ide_type': metadata.get('ide', 'unknown'),
+            'ide_type': ide_type,
             'model_name': metadata.get('model', 'unknown'),
             'git_repo_path': git_repo_path,
             'project_name': project_name,
@@ -144,14 +154,18 @@ def record_session_impl(
             'git_branch': git_branch,
             'git_commit': git_commit,
             'git_author': git_author,
-            'git_email': git_email
+            'git_email': git_email,
+            # 新增：版本信息
+            'devlake_mcp_version': platform_info['devlake_mcp_version'],
+            'ide_version': platform_info['ide_version'],
+            'data_source': 'mcp'  # MCP 数据来源（区别于 hook）
         }
 
-        # 7. 调用 DevLake API 创建会话（使用 context manager）
+        # 8. 调用 DevLake API 创建会话（使用 context manager）
         with DevLakeClient() as client:
             response = client.post('/api/ai-coding/sessions', session_data)
 
-        # 8. 返回结果
+        # 9. 返回结果
         return {
             'success': True,
             'session_id': session_id,
@@ -423,186 +437,189 @@ def after_edit_file_impl(
 
 # ============================================================================
 # MCP 工具装饰器（包装实现函数）
+# 注意：这些装饰器仅在 MCP 可用时才会生效
 # ============================================================================
 
-@mcp.tool
-def record_session(
-    session_id: str,
-    metadata: dict
-) -> dict:
-    """
-    记录 AI 会话的元数据和统计信息
+# 仅在 MCP 可用时注册工具
+if mcp is not None:
+    @mcp.tool
+    def record_session(
+        session_id: str,
+        metadata: dict
+    ) -> dict:
+        """
+        记录 AI 会话的元数据和统计信息
 
-    ## 调用时机
+        ## 调用时机
 
-    ✅ **每次对话结束时** ← 重要！必须调用
+        ✅ **每次对话结束时** ← 重要！必须调用
 
-    ## 用途
+        ## 用途
 
-    记录 AI 会话的元数据和统计信息，包括：
-    - 用户消息
-    - AI回复
-    - 使用的模型和 IDE
+        记录 AI 会话的元数据和统计信息，包括：
+        - 用户消息
+        - AI回复
+        - 使用的模型和 IDE
 
-    ## 参数
+        ## 参数
 
-    Args:
-        session_id: 会话 ID（必填，示例：1c1a4b88-8701-4dc0-b53f-9d5262ac6628，整个对话开始时应确定一个统一的sessionId，并在所有后续对话轮次操作中保持该ID不变）
-        metadata: 会话元数据（必填），支持字段：
-            - prompt_content: 用户消息（如 "实现用户登录功能"）
-            - response_content： AI回复
-            - model: 模型名称（如 "claude-sonnet-4-5"）
-            - ide: IDE 类型（如 "cursor", "claude-code"）
+        Args:
+            session_id: 会话 ID（必填，示例：1c1a4b88-8701-4dc0-b53f-9d5262ac6628，整个对话开始时应确定一个统一的sessionId，并在所有后续对话轮次操作中保持该ID不变）
+            metadata: 会话元数据（必填），支持字段：
+                - prompt_content: 用户消息（如 "实现用户登录功能"）
+                - response_content： AI回复
+                - model: 模型名称（如 "claude-sonnet-4-5"）
+                - ide: IDE 类型（如 "cursor", "claude-code"）
 
-    ## 返回值
+        ## 返回值
 
-    Returns:
-        dict: {
-            "success": true,
-            "session_id": "1c1a4b88-8701-4dc0-b53f-9d5262ac6628",
-            "timestamp": "2025-01-07T10:00:00Z",
-        }
+        Returns:
+            dict: {
+                "success": true,
+                "session_id": "1c1a4b88-8701-4dc0-b53f-9d5262ac6628",
+                "timestamp": "2025-01-07T10:00:00Z",
+            }
 
-    ## 注意事项
+        ## 注意事项
 
-    - ✅ **每次对话结束时必须调用**
-    - ✅ 文件变更场景：sessionId 必须与 beforeEditFile/afterEditFile 保持一致
-    - ✅ 必须提供 sessionId 和 metadata
-    - ❌ 不要在对话过程中多次调用
-    """
-    return record_session_impl(session_id, metadata)
+        - ✅ **每次对话结束时必须调用**
+        - ✅ 文件变更场景：sessionId 必须与 beforeEditFile/afterEditFile 保持一致
+        - ✅ 必须提供 sessionId 和 metadata
+        - ❌ 不要在对话过程中多次调用
+        """
+        return record_session_impl(session_id, metadata)
 
 
-@mcp.tool
-def before_edit_file(
-    session_id: str,
-    file_paths: List[str]
-) -> dict:
-    """
-    在文件内容变更操作前调用，记录变更前的文件状态
+    @mcp.tool
+    def before_edit_file(
+        session_id: str,
+        file_paths: List[str]
+    ) -> dict:
+        """
+        在文件内容变更操作前调用，记录变更前的文件状态
 
-    ## 调用时机
+        ## 调用时机
 
-    ✅ **文件内容变更操作前**：在执行以下操作**之前立即调用**
-    - Write, create_file - 创建新文件
-    - Edit, search_replace, edit_file - 修改现有文件
-    - delete_file - 删除文件
-    - NotebookEdit - 编辑 Jupyter Notebook
+        ✅ **文件内容变更操作前**：在执行以下操作**之前立即调用**
+        - Write, create_file - 创建新文件
+        - Edit, search_replace, edit_file - 修改现有文件
+        - delete_file - 删除文件
+        - NotebookEdit - 编辑 Jupyter Notebook
 
-    ❌ **不要在以下操作前调用**：
-    - Read, read_file - 读取文件（只读操作）
-    - Glob, Grep - 搜索文件（只读操作）
-    - Bash, shell - 执行命令（非文件操作）
+        ❌ **不要在以下操作前调用**：
+        - Read, read_file - 读取文件（只读操作）
+        - Glob, Grep - 搜索文件（只读操作）
+        - Bash, shell - 执行命令（非文件操作）
 
-    ## 用途
+        ## 用途
 
-    记录文件的原始状态（快照），保存到临时文件，供 afterEditFile 对比使用。
-    必须与 afterEditFile 成对出现。
+        记录文件的原始状态（快照），保存到临时文件，供 afterEditFile 对比使用。
+        必须与 afterEditFile 成对出现。
 
-    ## 参数
+        ## 参数
 
-    Args:
-        session_id: 会话 ID（必填，示例：1c1a4b88-8701-4dc0-b53f-9d5262ac6628，整个对话开始时应确定一个统一的sessionId，并在所有后续对话轮次操作中保持该ID不变）
-        file_paths: 即将变更的文件**绝对路径**列表
-            ⚠️ 必须使用绝对路径，如 ["/home/user/project/src/main.py", "/home/user/project/src/utils.py"]
-            ❌ 不要使用相对路径，如 ["src/main.py"]
+        Args:
+            session_id: 会话 ID（必填，示例：1c1a4b88-8701-4dc0-b53f-9d5262ac6628，整个对话开始时应确定一个统一的sessionId，并在所有后续对话轮次操作中保持该ID不变）
+            file_paths: 即将变更的文件**绝对路径**列表
+                ⚠️ 必须使用绝对路径，如 ["/home/user/project/src/main.py", "/home/user/project/src/utils.py"]
+                ❌ 不要使用相对路径，如 ["src/main.py"]
 
-    ## 返回值
+        ## 返回值
 
-    Returns:
-        dict: {
-            "success": true,
-            "session_id": "session-123",
-            "timestamp": "2025-01-07T10:00:00Z",
-            "files_snapshot": {
-                "/absolute/path/to/file1.py": {
-                    "exists": true,
-                    "line_count": 100,
-                    "size": 2048
+        Returns:
+            dict: {
+                "success": true,
+                "session_id": "session-123",
+                "timestamp": "2025-01-07T10:00:00Z",
+                "files_snapshot": {
+                    "/absolute/path/to/file1.py": {
+                        "exists": true,
+                        "line_count": 100,
+                        "size": 2048
+                    }
                 }
             }
-        }
-    ```
+        ```
 
-    ## 注意事项
-    - ✅ 必须在文件变更操作**之前**调用
-    - ✅ 必须使用绝对路径
-    - ❌ 不要对只读操作调用
-    - ❌ 不要使用相对路径
-    """
-    return before_edit_file_impl(session_id, file_paths)
+        ## 注意事项
+        - ✅ 必须在文件变更操作**之前**调用
+        - ✅ 必须使用绝对路径
+        - ❌ 不要对只读操作调用
+        - ❌ 不要使用相对路径
+        """
+        return before_edit_file_impl(session_id, file_paths)
 
 
-@mcp.tool
-def after_edit_file(
-    session_id: str,
-    file_paths: List[str],
-    metadata: dict = None
-) -> dict:
-    """
-    在文件内容变更操作后调用，记录变更后的文件状态
+    @mcp.tool
+    def after_edit_file(
+        session_id: str,
+        file_paths: List[str],
+        metadata: dict = None
+    ) -> dict:
+        """
+        在文件内容变更操作后调用，记录变更后的文件状态
 
-    ## 调用时机
+        ## 调用时机
 
-    ✅ **文件内容变更操作后**：在文件变更完成**之后立即调用**
+        ✅ **文件内容变更操作后**：在文件变更完成**之后立即调用**
 
-    必须在对应的 beforeEditFile 调用之后执行，两者必须成对出现。
+        必须在对应的 beforeEditFile 调用之后执行，两者必须成对出现。
 
-    ## 用途
+        ## 用途
 
-    1. 读取文件变更后的内容
-    2. 从临时文件加载变更前的内容
-    3. 计算变更差异（在服务端进行）
-    4. 上传到 DevLake API
-    5. 清理临时文件
+        1. 读取文件变更后的内容
+        2. 从临时文件加载变更前的内容
+        3. 计算变更差异（在服务端进行）
+        4. 上传到 DevLake API
+        5. 清理临时文件
 
-    ## 参数
+        ## 参数
 
-    Args:
-        session_id: 会话唯一标识（⚠️ 必须与 beforeEditFile 的 sessionId 一致）
-        file_paths: 已变更的文件**绝对路径**列表
-            ⚠️ 必须与 beforeEditFile 的 filePaths 完全一致
-            ⚠️ 必须使用绝对路径
-        metadata: 会话元数据（可选），支持字段：
-            - ide: IDE 类型（如 "cursor", "claude-code"）
-            - model: 模型名称（如 "claude-sonnet-4-5"）
+        Args:
+            session_id: 会话唯一标识（⚠️ 必须与 beforeEditFile 的 sessionId 一致）
+            file_paths: 已变更的文件**绝对路径**列表
+                ⚠️ 必须与 beforeEditFile 的 filePaths 完全一致
+                ⚠️ 必须使用绝对路径
+            metadata: 会话元数据（可选），支持字段：
+                - ide: IDE 类型（如 "cursor", "claude-code"）
+                - model: 模型名称（如 "claude-sonnet-4-5"）
 
-    ## 返回值
+        ## 返回值
 
-    Returns:
-        dict: {
-            "success": true,
-            "session_id": "session-123",
-            "timestamp": "2025-01-07T10:01:00Z",
-            "uploaded_count": 2,
-            "changes": [
-                {
-                    "file_path": "src/main.py",  # 相对路径（相对于 git root）
-                    "change_type": "edit",       # "create", "edit", "delete"
-                    "file_type": "py"
-                },
-                {
-                    "file_path": "src/utils.js",
-                    "change_type": "create",
-                    "file_type": "js"
-                }
-            ]
-        }
+        Returns:
+            dict: {
+                "success": true,
+                "session_id": "session-123",
+                "timestamp": "2025-01-07T10:01:00Z",
+                "uploaded_count": 2,
+                "changes": [
+                    {
+                        "file_path": "src/main.py",  # 相对路径（相对于 git root）
+                        "change_type": "edit",       # "create", "edit", "delete"
+                        "file_type": "py"
+                    },
+                    {
+                        "file_path": "src/utils.js",
+                        "change_type": "create",
+                        "file_type": "js"
+                    }
+                ]
+            }
 
 
-    ## 注意事项
+        ## 注意事项
 
-    - ✅ 必须在文件变更操作**之后**调用
-    - ✅ 必须与 beforeEditFile 成对出现
-    - ✅ sessionId 必须与 beforeEditFile 一致
-    - ✅ filePaths 必须与 beforeEditFile 完全一致
-    - ✅ 必须使用绝对路径
-    - ✅ **建议传递 metadata**（包含 ide 和 model 信息）
-    - ❌ 不要在 beforeEditFile 之前调用
-    - ❌ 不要使用不同的 sessionId
-    - ❌ 不要使用不同的 filePaths
-    """
-    return after_edit_file_impl(session_id, file_paths, metadata)
+        - ✅ 必须在文件变更操作**之后**调用
+        - ✅ 必须与 beforeEditFile 成对出现
+        - ✅ sessionId 必须与 beforeEditFile 一致
+        - ✅ filePaths 必须与 beforeEditFile 完全一致
+        - ✅ 必须使用绝对路径
+        - ✅ **建议传递 metadata**（包含 ide 和 model 信息）
+        - ❌ 不要在 beforeEditFile 之前调用
+        - ❌ 不要使用不同的 sessionId
+        - ❌ 不要使用不同的 filePaths
+        """
+        return after_edit_file_impl(session_id, file_paths, metadata)
 
 
 def main():
@@ -610,7 +627,36 @@ def main():
     启动 MCP 服务器
 
     使用 stdio 传输协议，适合与 Claude Desktop 等客户端集成。
+
+    注意：MCP Server 需要 Python 3.10+ 和 fastmcp 包。
     """
+    # 检查 MCP 是否可用
+    if not MCP_AVAILABLE:
+        print("\n" + "=" * 60, file=sys.stderr)
+        print("DevLake MCP Server - 启动失败", file=sys.stderr)
+        print("=" * 60, file=sys.stderr)
+
+        # 显示警告信息
+        warnings = get_compatibility_warnings()
+        for warning in warnings:
+            print(warning, file=sys.stderr)
+
+        print("\n可用功能:", file=sys.stderr)
+        print("  - Hooks 模式: ✓ 可用（适用于 Claude Code/Cursor hooks）", file=sys.stderr)
+        print("  - MCP Server: ✗ 不可用", file=sys.stderr)
+
+        if not HAS_MCP_SUPPORT:
+            print("\n推荐操作: 升级到 Python 3.10+ 以使用 MCP Server", file=sys.stderr)
+        else:
+            print("\n推荐操作: pip install 'devlake-mcp[mcp]'", file=sys.stderr)
+
+        print("=" * 60, file=sys.stderr)
+        sys.exit(1)
+
+    # 配置日志（读取环境变量）
+    configure_logging()
+
+    print("✓ MCP Server 启动成功 (FastMCP)", file=sys.stderr)
     mcp.run()  # 默认使用 stdio transport
 
 
