@@ -33,29 +33,59 @@ from .constants import (
 # 配置日志
 logger = logging.getLogger(__name__)
 
+# 持久化数据目录名称
+DATA_DIR_NAME = '.devlake'
 
-def get_temp_dir() -> Path:
+
+def get_data_dir(persistent: bool = False) -> Path:
     """
-    获取跨平台的临时目录
+    获取跨平台的数据存储目录
 
     优先级：
-    1. 环境变量 DEVLAKE_MCP_TEMP_DIR
-    2. 系统临时目录 + /devlake_mcp
+    1. 环境变量 DEVLAKE_MCP_DATA_DIR (优先级最高,覆盖 persistent 参数)
+    2. persistent=True: 用户主目录 ~/.devlake (持久化存储)
+    3. persistent=False: 系统临时目录/devlake_mcp (临时存储)
+
+    Args:
+        persistent: True 使用持久化目录 (~/.devlake),
+                   False 使用临时目录 (系统temp/devlake_mcp)
 
     Returns:
-        临时目录路径
+        数据存储目录路径
+
+        持久化目录 (persistent=True):
+        - Windows: C:\\Users\\xxx\\.devlake
+        - macOS:   /Users/xxx/.devlake
+        - Linux:   /home/xxx/.devlake
+
+        临时目录 (persistent=False):
         - Windows: C:\\Users\\xxx\\AppData\\Local\\Temp\\devlake_mcp
         - macOS:   /var/folders/xxx/T/devlake_mcp
         - Linux:   /tmp/devlake_mcp
-    """
-    custom_dir = os.getenv('DEVLAKE_MCP_TEMP_DIR')
-    if custom_dir:
-        temp_dir = Path(custom_dir)
-    else:
-        temp_dir = Path(tempfile.gettempdir()) / TEMP_DIR_NAME
 
-    temp_dir.mkdir(parents=True, exist_ok=True)
-    return temp_dir
+    Examples:
+        >>> # 持久化存储(session state, generation state, retry queue)
+        >>> data_dir = get_data_dir(persistent=True)
+        >>> # 临时存储(before_content 快照文件)
+        >>> temp_dir = get_data_dir(persistent=False)
+        >>> # 自定义路径
+        >>> os.environ['DEVLAKE_MCP_DATA_DIR'] = '/custom/path'
+        >>> data_dir = get_data_dir()  # 返回 /custom/path
+    """
+    # 优先使用环境变量
+    custom_dir = os.getenv('DEVLAKE_MCP_DATA_DIR')
+    if custom_dir:
+        data_dir = Path(custom_dir)
+    elif persistent:
+        # 持久化目录: ~/.devlake
+        data_dir = Path.home() / DATA_DIR_NAME
+    else:
+        # 临时目录: /tmp/devlake_mcp (跨平台兼容)
+        data_dir = Path(tempfile.gettempdir()) / TEMP_DIR_NAME
+
+    # 确保目录存在
+    data_dir.mkdir(parents=True, exist_ok=True)
+    return data_dir
 
 
 def get_temp_file_path(session_id: str, file_path: str) -> str:
@@ -72,8 +102,8 @@ def get_temp_file_path(session_id: str, file_path: str) -> str:
     # 使用文件路径的 hash 作为文件名（避免路径过长）
     file_hash = hashlib.md5(file_path.encode()).hexdigest()[:16]
 
-    # 获取跨平台临时目录
-    temp_dir = get_temp_dir()
+    # 获取跨平台临时目录（使用临时存储模式）
+    temp_dir = get_data_dir(persistent=False)
 
     # 临时文件名：{session_id}_{file_hash}.before
     temp_file = temp_dir / f"{session_id}_{file_hash}.before"
